gs_quant.timeseries.analysis.first — gs_quant 0.1 documentation

# gs_quant.timeseries.analysis.first

`first`(x)

  First value of series

  Parameters

    x (`Series`) – time series

  Return type

    `Series`

  Returns

    time series of first value

  Usage

  Return series with first value of X for all dates:

  \(R_t = X_0\)

  where \(X_0\) is the first value in the series

  Examples

  Last value of series:

      >>> series = generate_series(100)
      >>> returns = first(series)

  See also

  `last()`